gRPC Typing Stubs for Python
============================

This is a PEP-561-compliant stub-only package which provides type information of
`gRPC <https://grpc.io>`_.

Install using pip::

    pip install grpc-stubs


